@@ -2,12 +2,12 @@
 #######################################################################
 """The converterannotator class.
 
-$Id: converterannotator.py 49600 2008-01-21 11:08:39Z cray $
+$Id: converterannotator.py 49876 2008-02-02 14:18:55Z cray $
 """
 __author__  = "Ischenko Valera, 2006"
 __license__ = "GPL"
-__version__ = "$Revision: 49600 $"
-__date__ = "$Date: 2008-01-21 14:08:39 +0300 (Пнд, 21 Янв 2008) $"
+__version__ = "$Revision: 49876 $"
+__date__ = "$Date: 2008-02-02 17:18:55 +0300 (Сбт, 02 Фев 2008) $"
 __credits__ = """Andrey Orlov, for idea and common control"""
 
 from zope.interface import implements
@@ -30,14 +30,18 @@ class ConverterAnnotator(ConverterBase):
     __doc__ = IConverterAnnotator.__doc__
     
     implements(IConverterAnnotator,IConverter)
-    pattern_sentences = "(?u)(?:(?<=\s)|(?<=\A))[^\.!?;]+\.(?:(?=\s)|(?=\Z))"
+    pattern_sentences = "(?uL)(?:(?<=^)|(?<=\s))([^~=\.?!;]+[\.?!;])(?=\s|$)"
     pattern_word = "(?u)(?:(?<=\s)|(?<=\A))[^\s]+(?:(?=\s)|(?=\.)|(?=\Z))"
+    _keywords = ""
+    _normalisation = True
     
     def __init__(self, keywords, best_count = 10, normalisation = True, minimal4norm = 4):
-        ''' Get text and keywords as necessary parametrs. Unnecessary parametrs is count of sentences in annotation and use of normalization '''
+        """ Get text and keywords as necessary parametrs. Unnecessary
+        parametrs is count of sentences in annotation and use of
+        normalization """
         self.best_count = best_count
-        self.normalisation = normalisation
         self.minimal4norm = minimal4norm
+        self.normalisation = normalisation
         self.keywords = keywords
 
     def _getNormalisation(self) :
