@@ -4,18 +4,18 @@
 
 Interfaces for the Zope 3 based converterannotator package
 
-$Id: interfaces.py 49600 2008-01-21 11:08:39Z cray $
+$Id: interfaces.py 49876 2008-02-02 14:18:55Z cray $
 """
 __author__  = "Ischenko Valera, 2006"
 __license__ = "GPL"
-__version__ = "$Revision: 49600 $"
+__version__ = "$Revision: 49876 $"
  
 from zope.interface import Interface
 from zope.schema import Text, TextLine, Field, Int, Bool
 from zope.app.container.interfaces import IContained, IContainer
 from ng.app.converter.converter.interfaces import IConverter
 
-class IConverterAnnotator(IConverter):
+class IConverterAnnotatorAdd(Interface) :
     """ A converterannotator object, parameters """
 
     keywords = Text(
@@ -33,7 +33,7 @@ class IConverterAnnotator(IConverter):
     pattern_sentences = TextLine(
            title=u"Pattern Sentences",
            description=u"Pattern to split text onto by sentences.",
-           default=u"(?uL)\s+[^\.]+\.",
+           default=u"(?uL)(?:(?<=^)|(?<=\s))([^~=\.?!;]+[\.?!;])(?=\s|$)",
            required=True)
 
     best_count = Int(
@@ -60,4 +60,7 @@ class IConverterAnnotator(IConverter):
            default=1,
            required=False)
 	   
+class IConverterAnnotator(IConverter,IConverterAnnotatorAdd):
+    """ A converterannotator object, parameters """
+
     
\ No newline at end of file
