@@ -2,11 +2,11 @@
 #######################################################################
 """ConverterChain class for the Zope 3 based convertercall package
 
-$Id: converterchain.py 49600 2008-01-21 11:08:39Z cray $
+$Id: converterchain.py 49876 2008-02-02 14:18:55Z cray $
 """
 __author__  = "Andrey Orlov, 2008"
 __license__ = "GPL"
-__version__ = "$Revision: 49600 $"
+__version__ = "$Revision: 49876 $"
 
 from zope.interface import implements,implementedBy
 from interfaces import IConverterChain
@@ -52,6 +52,8 @@ class ConverterChain(ConverterBase):
 
     @property
     def mtime(self) :
-        return max(super(ConverterChain,self).mtime,
-            max([ getUtility(IConverter,context=self,name=x).mtime for x in self.chain ])
-            )
\ No newline at end of file
+        try :
+            mtc = max([ getUtility(IConverter,context=self,name=x).mtime for x in self.chain ])
+        except ValueError :
+            return super(ConverterChain,self).mtime
+        return max(super(ConverterChain,self).mtime,mtc)
