@@ -2,11 +2,11 @@
 #######################################################################
 """Interfaces for the Zope 3 based convertercall package
 
-$Id: interfaces.py 49600 2008-01-21 11:08:39Z cray $
+$Id: interfaces.py 49876 2008-02-02 14:18:55Z cray $
 """
 __author__  = "Andrey Orlov, 2008"
 __license__ = "GPL"
-__version__ = "$Revision: 49600 $"
+__version__ = "$Revision: 49876 $"
  
 from zope.interface import implements, Interface, alsoProvides
 from zope.schema import Text, TextLine, Field, Bool, Datetime, Choice, Tuple
@@ -16,9 +16,8 @@ from ng.app.converter.converter.interfaces import IConverter
 from ng.app.converter.convertervocabulary import ConverterVocabulary
 from zope.schema.vocabulary import SimpleVocabulary
 
-
-class IConverterChain(IConverter):
-    """ A convertercall object """
+class IConverterChainAdd(Interface) :
+    """ A converterchain data """
 
     iftype = Choice(title=u'Condition Type',
         vocabulary = SimpleVocabulary.fromValues(['ifall','ifempty','ifregexp','ifnotregexp']),
@@ -42,3 +41,5 @@ class IConverterChain(IConverter):
             )
         )
         
+class IConverterChain(IConverter,IConverterChainAdd):
+    """ A conerterchain object """
\ No newline at end of file
