@@ -4,11 +4,11 @@
 
 Interfaces for the Zope 3 based converterchain package
 
-$Id: interfaces.py 49600 2008-01-21 11:08:39Z cray $
+$Id: interfaces.py 49876 2008-02-02 14:18:55Z cray $
 """
 __author__  = "Arvid, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 49600 $"
+__version__ = "$Revision: 49876 $"
 
 from zope.interface import Interface
 from zope.schema import Text, TextLine, Field
@@ -19,7 +19,10 @@ from zope.app.container.constraints import ItemTypePrecondition
 
 from ng.app.converter.converter.interfaces import IConverter
 
-class IConverterContainer(IOrderedContainer,IConverter):
+class IConverterContainerAdd(Interface) :
+    pass
+
+class IConverterContainer(IOrderedContainer,IConverter, IConverterContainerAdd):
     """ A convertercontainer object """
     
     def __setitem__(name, object):
