@@ -2,11 +2,11 @@
 #######################################################################
 """Interfaces for the Zope 3 based converterhead package
 
-$Id: interfaces.py 49600 2008-01-21 11:08:39Z cray $
+$Id: interfaces.py 49876 2008-02-02 14:18:55Z cray $
 """
 __author__  = "Andrey Orlov, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 49600 $"
+__version__ = "$Revision: 49876 $"
  
 from zope.interface import Interface
 
@@ -15,9 +15,9 @@ from zope.app.container.interfaces import IContained, IContainer
 from zope.app.container.constraints import ItemTypePrecondition
 from zope.app.container.constraints import ContainerTypesConstraint
 from ng.app.converter.converter.interfaces import IConverter
+
+class IConverterHeadAdd(Interface) :
                 
-class IConverterHead(IConverter) :
-    """ A converterhead object """
 
     regexp = TextLine(
            title=u"Regular Expression",
@@ -43,3 +43,5 @@ class IConverterHead(IConverter) :
            default=10,
            required=True)
                                                                         
+class IConverterHead(IConverter,IConverterHeadAdd) :
+    """ A converterhead object """
