@@ -4,19 +4,19 @@
 
 Interfaces for the Zope 3 based converterregexp package
 
-$Id: interfaces.py 49600 2008-01-21 11:08:39Z cray $
+$Id: interfaces.py 49876 2008-02-02 14:18:55Z cray $
 """
 __author__  = "Andrey Orlov, 2006"
 __license__ = "GPL"
-__version__ = "$Revision: 49600 $"
+__version__ = "$Revision: 49876 $"
  
 from zope.interface import Interface
 from zope.schema import Text, TextLine, Field
 from zope.app.container.interfaces import IContained, IContainer
 from ng.app.converter.converter.interfaces import IConverter
 
-class IConverterRegexp(IConverter):
-    """ A converterregexp object """
+class IConverterRegexpAdd(Interface):
+    """ A converterregexp object data """
 
     regexp = TextLine(
            title=u"Regular Expression",
@@ -30,3 +30,6 @@ class IConverterRegexp(IConverter):
            default=u"",
            required=True)
                                                                         
+
+class IConverterRegexp(IConverter, IConverterRegexpAdd):
+    """ A converterregexp object """
\ No newline at end of file
