@@ -4,18 +4,18 @@
 
 Interfaces for the Zope 3 based converterrest package
 
-$Id: interfaces.py 49600 2008-01-21 11:08:39Z cray $
+$Id: interfaces.py 49876 2008-02-02 14:18:55Z cray $
 """
 __author__  = "Arvid, 2006"
 __license__ = "GPL"
-__version__ = "$Revision: 49600 $"
+__version__ = "$Revision: 49876 $"
  
 from zope.interface import Interface
 from zope.schema import Text, TextLine, Field, Int
 from zope.app.container.interfaces import IContained, IContainer
 from ng.app.converter.converter.interfaces import IConverter
 
-class IConverterReST(IConverter):
+class IConverterReSTAdd(Interface) :
     """ A converterrest interface"""
     
     title = TextLine(
@@ -42,3 +42,6 @@ class IConverterReST(IConverter):
                 title = u"Halt Level",
                 default = 6
                 )
+
+class IConverterReST(IConverter,IConverterReSTAdd):
+    """ A converterrest interface"""
\ No newline at end of file
