@@ -2,11 +2,11 @@
 #######################################################################
 """Interfaces for the Zope 3 based converterselect package
 
-$Id: interfaces.py 49600 2008-01-21 11:08:39Z cray $
+$Id: interfaces.py 49876 2008-02-02 14:18:55Z cray $
 """
 __author__  = "Andrey Orlov, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 49600 $"
+__version__ = "$Revision: 49876 $"
  
 from zope.interface import Interface
 
@@ -16,8 +16,8 @@ from zope.app.container.constraints import ItemTypePrecondition
 from zope.app.container.constraints import ContainerTypesConstraint
 from ng.app.converter.converter.interfaces import IConverter
                 
-class IConverterSelect(IConverter) :
-    """ A converterselect object """
+class IConverterSelectAdd(Interface) :
+    """ A converterselect object data """
 
     title = TextLine(title = u"Title", default=u"Converter Select")
                                                                         
@@ -26,4 +26,7 @@ class IConverterSelect(IConverter) :
     dwin = Int(title=u"Window delta",default=50,required=True);    
 
     threshold = Int(title=u"Threshold",default=3,required=True);    
+
+class IConverterSelect(IConverter,IConverterSelectAdd) :
+    """ A converterselect object """
     
\ No newline at end of file
