@@ -2,11 +2,11 @@
 #######################################################################
 """Interfaces for the Zope 3 based converterst package
 
-$Id: interfaces.py 49600 2008-01-21 11:08:39Z cray $
+$Id: interfaces.py 49876 2008-02-02 14:18:55Z cray $
 """
 __author__  = "Andrey Orlov, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 49600 $"
+__version__ = "$Revision: 49876 $"
  
 from zope.interface import Interface
 
@@ -16,9 +16,11 @@ from zope.app.container.constraints import ItemTypePrecondition
 from zope.app.container.constraints import ContainerTypesConstraint
 from ng.app.converter.converter.interfaces import IConverter
                 
-class IConverterST(IConverter) :
-    """ A converterhead object """
+class IConverterSTAdd(Interface) :
+    """ A structured text converter object data """
 
     title = TextLine(title = u"Title", default=u"Converter ST")
                                                                         
+class IConverterST(IConverter,IConverterSTAdd) :
+    """ A structured text converter object """
     
\ No newline at end of file
