@@ -4,11 +4,11 @@
 
 Interfaces for the Zope 3 based converterxslt package
 
-$Id: interfaces.py 49600 2008-01-21 11:08:39Z cray $
+$Id: interfaces.py 49876 2008-02-02 14:18:55Z cray $
 """
 __author__  = "Anatoly Bubenkov, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 49600 $"
+__version__ = "$Revision: 49876 $"
  
 from zope.interface import Interface
 from zope.schema import Text, TextLine, Field, Choice, BytesLine, Bytes
@@ -19,14 +19,16 @@ from zope.app.container.constraints import ContainerTypesConstraint
 from ng.app.converter.converter.interfaces import IConverter
 from charsetvocabulary import charsetvocabulary 
 
-class IConverterXSLT(IConverter):
-    """Converter XSLT content"""
+class IConverterXSLTAdd(Interface):
+    """Converter XSLT content data"""
     
     html_charset = Choice(title = u'HTML Charset',
                           description = u'Select an charset',
                           required = False,
                           vocabulary = charsetvocabulary)
     
+class IConverterXSLT(IConverter,IConverterXSLTAdd):
+    """Converter XSLT content"""
 
 class IConverterXSLTSchema(IConverterXSLT, IFile):
     """Schema for IConverterXSLT"""
