@@ -2,11 +2,11 @@
 #######################################################################
 """The object2psadapter class.
 
-$Id: object2psadapter.py 49600 2008-01-21 11:08:39Z cray $
+$Id: object2psadapter.py 49876 2008-02-02 14:18:55Z cray $
 """
 __author__  = "Ischenko Valera, 2006"
 __license__ = "GPL"
-__version__ = "$Revision: 49600 $"
+__version__ = "$Revision: 49876 $"
 
 from zope.interface import implements
 from interfaces import IPropertySheet, IAttributeConvertable
@@ -83,6 +83,9 @@ class Object2PSadapterBase(object):
 class Object2PSadapter(Object2PSadapterBase):
     """ """
     implements(IPropertySheet)
+
+    def get(self,key,default) :
+        return self.attrdict.get(key,default)
 	
     def __getitem__(self, key):
         return self.attrdict[key]
